@@ -34,6 +34,10 @@ CGAP_ENV_WEBPROD_NEW = 'cgap-green'
 # CGAP_ENV_WEBPROD2_NEW is meaningless here. See CGAP_ENV_STAGING_NEW.
 CGAP_ENV_WOLF_NEW = 'cgap-wolf'  # Maybe not used
 
+# The bucket names were allocated originally and needn't change.
+
+FF_PROD_BUCKET_ENV = FF_ENV_WEBPROD
+CGAP_PROD_BUCKET_ENV = CGAP_ENV_WEBPROD
 
 # Done this way to get maximally compatible behavior.
 FOURFRONT_STG_OR_PRD_TOKENS = ['webprod', 'blue', 'green']
@@ -41,10 +45,41 @@ FOURFRONT_STG_OR_PRD_NAMES = ['staging', 'stagging', 'data']
 
 # Done this way because it's safer going forward.
 CGAP_STG_OR_PRD_TOKENS = []
-CGAP_STG_OR_PRD_NAMES = [CGAP_ENV_WEBPROD, CGAP_ENV_PRODUCTION_GREEN, CGAP_ENV_PRODUCTION_BLUE]
+CGAP_STG_OR_PRD_NAMES = [CGAP_ENV_WEBPROD, CGAP_ENV_PRODUCTION_GREEN, CGAP_ENV_PRODUCTION_BLUE, 'cgap']
 
 
-# These operate as pairs. Don't add extras.
+FF_PUBLIC_URL_STG = 'http://staging.4dnucleome.org'
+FF_PUBLIC_URL_PRD = 'https://data.4dnucleome.org'
+
+FF_PUBLIC_URLS = {
+    'staging': FF_PUBLIC_URL_STG,
+    'data': FF_PUBLIC_URL_PRD,
+}
+
+CGAP_PUBLIC_URL_STG = 'https://staging.cgap.hms.harvard.edu'  # This is a stopgap for testing and may have to change
+CGAP_PUBLIC_URL_PRD = 'https://cgap.hms.harvard.edu'
+
+CGAP_PUBLIC_URLS = {
+    'cgap': CGAP_PUBLIC_URL_PRD,
+    'data': CGAP_PUBLIC_URL_PRD,
+    'staging': CGAP_PUBLIC_URL_STG,
+}
+
+BEANSTALK_PROD_BUCKET_ENVS = {
+    'staging': FF_PROD_BUCKET_ENV,
+    'data': FF_PROD_BUCKET_ENV,
+    FF_ENV_WEBPROD: FF_PROD_BUCKET_ENV,
+    FF_ENV_WEBPROD2: FF_PROD_BUCKET_ENV,
+    FF_ENV_PRODUCTION_BLUE: FF_PROD_BUCKET_ENV,
+    FF_ENV_PRODUCTION_GREEN: FF_PROD_BUCKET_ENV,
+    'cgap': CGAP_PROD_BUCKET_ENV,
+    CGAP_ENV_PRODUCTION_BLUE: CGAP_PROD_BUCKET_ENV,
+    CGAP_ENV_PRODUCTION_GREEN: CGAP_PROD_BUCKET_ENV,
+    CGAP_ENV_WEBPROD: CGAP_PROD_BUCKET_ENV,
+    CGAP_ENV_PRODUCTION_BLUE_NEW: CGAP_PROD_BUCKET_ENV,
+    CGAP_ENV_PRODUCTION_GREEN_NEW: CGAP_PROD_BUCKET_ENV,
+}
+
 BEANSTALK_PROD_MIRRORS = {
 
     FF_ENV_PRODUCTION_BLUE: FF_ENV_PRODUCTION_GREEN,
@@ -61,7 +96,6 @@ BEANSTALK_PROD_MIRRORS = {
 
 }
 
-
 BEANSTALK_TEST_ENVS = [
 
     FF_ENV_HOTSEAT,
@@ -95,6 +129,34 @@ def blue_green_mirror_env(envname):
         return None
 
 
+def prod_bucket_env(envname):
+    """
+    Given a production-class envname returns the envname of the associated production bucket.
+    For other envnames that aren't production envs, this returns None.
+
+    The envname is something that is either a staging or production env, in particular something
+    that is_stg_or_prd_env returns True for.
+
+    This is intended for use when configuring a beanstalk. This functionality is agnostic
+    about whether we're asking on behalf of CGAP or Fourfront, and whether we're using an old or new
+    naming scheme. Just give the current envname as an argument, and it will know (by declaration,
+    see the BEANSTALK_PROD_ENV_BUCKET_TOKENS table) what the appropriate production bucket name token is for
+    that ecosystem.
+    """
+    return BEANSTALK_PROD_BUCKET_ENVS.get(envname)
+
+
+def public_url_mappings(envname):
+    """
+    Returns a table of the public URLs we use for the ecosystem in which the envname resides.
+    For example, if envname is a CGAP URL, this returns a set table of CGAP public URLs,
+    and otherwise it returns a set of Fourfront URLs.
+
+    The envname may be 'cgap', 'data', 'staging', or an environment name.
+    """
+    return CGAP_PUBLIC_URLS if is_cgap_env(envname) else FF_PUBLIC_URLS
+
+
 def is_cgap_env(envname):
     """
     Returns True of the given string looks like a CGAP elasticbeanstalk environment name.
